"""Add menu and all the commands to Nuke's UI."""

# Import third-party modules
import nuke  # pylint:disable=import-error
import nukescripts  # pylint:disable=import-error

# Import local modules
from smartCommand import osl as smartcommand
from smartCommand.constants import ICONS
from smartCommand.helper import create_default_data_roots
from smartCommand.helper import initialize_hotkeys


def register_menu():
    """Register menu and commands."""
    sc_menu = nuke.menu("Nuke").addMenu("cragl/smartCommand",
                                        icon=ICONS["logo"])
    sc_menu.addCommand(
        "smartCommander", lambda: smartcommand.show_smartcommander(
            floating=True), "F12")

    sc_menu.addSeparator()
    sc_menu.addCommand("&about", smartcommand.show_about_window)


def register_pane():
    """Register smartCommander to pane."""
    nukescripts.panels.registerWidgetAsPanel(
        "smartcommand.show_smartcommander", "smartCommander",
        "com.cragl.smartCommand")


def init():
    """Initialize ui elements."""
    register_menu()
    register_pane()
    initialize_hotkeys()
    create_default_data_roots()


init()
